@@ -58,24 +58,6 @@ static LRESULT CALLBACK hookProcMouse(int nCode, WPARAM wParam, LPARAM lParam)
 
 DockingCont::DockingCont()
 {
-	_isMouseOver		= FALSE;
-	_isMouseClose		= FALSE;
-	_isMouseDown		= FALSE;
-	_isFloating			= false;
-	_isTopCaption		= CAPTION_TOP;
-	_dragFromTab		= FALSE;
-	_hContTab			= NULL;
-	_hDefaultTabProc	= NULL;
-	_beginDrag			= FALSE;
-	_prevItem			= 0;
-	_hFont				= NULL;
-	_bTabTTHover		= FALSE;
-	_bCaptionTT			= FALSE;
-	_bCapTTHover		= FALSE;
-	_hoverMPos			= posClose;
-	_bDrawOgLine		= TRUE;
-	_vTbData.clear();
-
 	_captionHeightDynamic = NppParameters::getInstance()._dpiManager.scaleY(_captionHeightDynamic);
 	_captionGapDynamic = NppParameters::getInstance()._dpiManager.scaleY(_captionGapDynamic);
 	_closeButtonPosLeftDynamic = NppParameters::getInstance()._dpiManager.scaleX(_closeButtonPosLeftDynamic);
@@ -123,11 +105,11 @@ void DockingCont::doDialog(bool willBeShown, bool isFloating)
 			::ShowWindow(_hCaption, SW_SHOW);
 		}
 
-		//If you want defualt GUI font
-		LOGFONT lfTab{ NppParameters::getDefaultGUIFont() };
+		//If you want default GUI font
+		LOGFONT lfTab{ DPIManagerV2::getDefaultGUIFontForDpi(_hParent) };
 		_hFont = ::CreateFontIndirect(&lfTab);
 
-		LOGFONT lfCaption{ NppParameters::getDefaultGUIFont(NppParameters::DefaultFontType::smcaption) };
+		LOGFONT lfCaption{ DPIManagerV2::getDefaultGUIFontForDpi(_hParent, DPIManagerV2::FontType::smcaption) };
 		_hFontCaption = ::CreateFontIndirect(&lfCaption);
 	}
 
@@ -135,7 +117,7 @@ void DockingCont::doDialog(bool willBeShown, bool isFloating)
 }
 
 
-tTbData* DockingCont::createToolbar(tTbData data)
+tTbData* DockingCont::createToolbar(const tTbData& data)
 {
 	tTbData *pTbData = new tTbData;
 
@@ -164,13 +146,13 @@ tTbData* DockingCont::createToolbar(tTbData data)
 }
 
 
-void DockingCont::removeToolbar(tTbData TbData)
+void DockingCont::removeToolbar(const tTbData& data)
 {
 	// remove from list
 	// items in _vTbData are removed in the loop so _vTbData.size() should be checked in every iteration
 	for (size_t iTb = 0 ; iTb < _vTbData.size(); ++iTb)
 	{
-		if (_vTbData[iTb]->hClient == TbData.hClient)
+		if (_vTbData[iTb]->hClient == data.hClient)
 		{
 			// remove tab
 			removeTab(_vTbData[iTb]);
@@ -240,9 +222,9 @@ tTbData* DockingCont::getDataOfActiveTb()
 
 	if (iItem != -1)
 	{
-		TCITEM	tcItem	= {};
+		TCITEM tcItem {};
 
-		tcItem.mask		= TCIF_PARAM;
+		tcItem.mask = TCIF_PARAM;
 		::SendMessage(_hContTab, TCM_GETITEM, iItem, reinterpret_cast<LPARAM>(&tcItem));
 		pTbData = (tTbData*)tcItem.lParam;
 	}
@@ -253,7 +235,7 @@ tTbData* DockingCont::getDataOfActiveTb()
 vector<tTbData*> DockingCont::getDataOfVisTb()
 {
 	vector<tTbData*> vTbData;
-	TCITEM tcItem = {};
+	TCITEM tcItem {};
 	int iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
 
 	tcItem.mask	= TCIF_PARAM;
@@ -268,7 +250,7 @@ vector<tTbData*> DockingCont::getDataOfVisTb()
 
 bool DockingCont::isTbVis(tTbData* data)
 {
-	TCITEM tcItem = {};
+	TCITEM tcItem {};
 	int iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
 
 	tcItem.mask	= TCIF_PARAM;
@@ -363,7 +345,7 @@ LRESULT DockingCont::runProcCaption(HWND hwnd, UINT Message, WPARAM wParam, LPAR
 		}
 		case WM_MOUSEMOVE:
 		{
-			POINT	pt			= {};
+			POINT pt {};
 
 			// get correct cursor position
 			::GetCursorPos(&pt);
@@ -422,8 +404,8 @@ LRESULT DockingCont::runProcCaption(HWND hwnd, UINT Message, WPARAM wParam, LPAR
 		}
 		case WM_MOUSEHOVER:
 		{
-			RECT	rc	= {};
-			POINT	pt	= {};
+			RECT rc {};
+			POINT pt {};
 
 
 			// get mouse position
@@ -468,18 +450,18 @@ LRESULT DockingCont::runProcCaption(HWND hwnd, UINT Message, WPARAM wParam, LPAR
 
 void DockingCont::drawCaptionItem(DRAWITEMSTRUCT *pDrawItemStruct)
 {
-	HBRUSH		bgbrush		= NULL;
-	HFONT		hOldFont	= NULL;
-	RECT		rc			= pDrawItemStruct->rcItem;
-	HDC			hDc			= pDrawItemStruct->hDC;
-	HPEN		hPen		= ::CreatePen(PS_SOLID, 1, ::GetSysColor(COLOR_BTNSHADOW));
-	BITMAP		bmp			= {};
-	HBITMAP		hBmpCur		= NULL;
-	HBITMAP		hBmpOld 	= NULL;
-	HBITMAP		hBmpNew		= NULL;
+	HBRUSH bgbrush = NULL;
+	HFONT hOldFont = NULL;
+	RECT rc = pDrawItemStruct->rcItem;
+	HDC hDc = pDrawItemStruct->hDC;
+	HPEN hPen = ::CreatePen(PS_SOLID, 1, ::GetSysColor(COLOR_BTNSHADOW));
+	BITMAP bmp {};
+	HBITMAP hBmpCur = NULL;
+	HBITMAP hBmpOld = NULL;
+	HBITMAP hBmpNew = NULL;
 	int length = static_cast<int32_t>(_pszCaption.length());
 
-	int nSavedDC			= ::SaveDC(hDc);
+	int nSavedDC = ::SaveDC(hDc);
 
 	// begin with paint
 	::SetBkMode(hDc, TRANSPARENT);
@@ -578,7 +560,7 @@ void DockingCont::drawCaptionItem(DRAWITEMSTRUCT *pDrawItemStruct)
 		rc.right	= rc.bottom - rc.top;
 		rc.bottom	+= 14;
 
-		LOGFONT lf{ NppParameters::getDefaultGUIFont(NppParameters::DefaultFontType::smcaption) };
+		LOGFONT lf{ DPIManagerV2::getDefaultGUIFontForDpi(_hParent, DPIManagerV2::FontType::smcaption) };
 		lf.lfEscapement = 900;
 		hFont = ::CreateFontIndirect(&lf);
 		if (hFont == nullptr)
@@ -612,7 +594,7 @@ void DockingCont::drawCaptionItem(DRAWITEMSTRUCT *pDrawItemStruct)
 	{
 		if (_hFont == nullptr)
 		{
-			LOGFONT lf{ NppParameters::getDefaultGUIFont() };
+			LOGFONT lf{ DPIManagerV2::getDefaultGUIFontForDpi(_hParent) };
 			_hFont = ::CreateFontIndirect(&lf);
 		}
 		auto hOld = static_cast<HFONT>(::SelectObject(hDc, _hFont));
@@ -670,7 +652,7 @@ void DockingCont::drawCaptionItem(DRAWITEMSTRUCT *pDrawItemStruct)
 
 eMousePos DockingCont::isInRect(HWND hwnd, int x, int y)
 {
-	RECT		rc;
+	RECT rc {};
 	eMousePos	ret	= posOutside;
 
 	::GetWindowRect(hwnd, &rc);
@@ -721,7 +703,7 @@ LRESULT DockingCont::runProcTab(HWND hwnd, UINT Message, WPARAM wParam, LPARAM l
 				break;
 			}
 
-			RECT rc{};
+			RECT rc {};
 			::GetClientRect(hwnd, &rc);
 			::FillRect(reinterpret_cast<HDC>(wParam), &rc, NppDarkMode::getDarkerBackgroundBrush());
 
@@ -783,7 +765,7 @@ LRESULT DockingCont::runProcTab(HWND hwnd, UINT Message, WPARAM wParam, LPARAM l
 
 				dis.itemState |= ODS_NOFOCUSRECT; // maybe, does it handle it already?
 
-				RECT rcIntersect = {};
+				RECT rcIntersect {};
 				if (IntersectRect(&rcIntersect, &ps.rcPaint, &dis.rcItem))
 				{
 					dis.rcItem.top += NppParameters::getInstance()._dpiManager.scaleY(1);
@@ -858,9 +840,9 @@ LRESULT DockingCont::runProcTab(HWND hwnd, UINT Message, WPARAM wParam, LPARAM l
 		}
 		case WM_MBUTTONUP:
 		{
-			int				iItem	= 0;
-			TCITEM			tcItem	= {};
-			TCHITTESTINFO	info	= {};
+			int iItem	= 0;
+			TCITEM tcItem {};
+			TCHITTESTINFO info {};
 
 			// get selected sub item
 			info.pt.x = LOWORD(lParam);
@@ -925,8 +907,8 @@ LRESULT DockingCont::runProcTab(HWND hwnd, UINT Message, WPARAM wParam, LPARAM l
 					}
 					else if (iItem != _iLastHovered)
 					{
-						TCITEM	tcItem	= {};
-						RECT	rc		= {};
+						TCITEM tcItem {};
+						RECT rc {};
 
 						// destroy old tooltip
 						toolTip.destroy();
@@ -955,10 +937,10 @@ LRESULT DockingCont::runProcTab(HWND hwnd, UINT Message, WPARAM wParam, LPARAM l
 
 		case WM_MOUSEHOVER:
 		{
-			int				iItem	= 0;
-			TCITEM			tcItem	= {};
-			RECT			rc		= {};
-			TCHITTESTINFO	info	= {};
+			int iItem = 0;
+			TCITEM tcItem {};
+			RECT rc {};
+			TCHITTESTINFO info {};
 
 			// get selected sub item
 			info.pt.x = LOWORD(lParam);
@@ -1032,11 +1014,11 @@ LRESULT DockingCont::runProcTab(HWND hwnd, UINT Message, WPARAM wParam, LPARAM l
 
 void DockingCont::drawTabItem(DRAWITEMSTRUCT *pDrawItemStruct)
 {
-	TCITEM	tcItem		= {};
-	RECT	rc			= pDrawItemStruct->rcItem;
+	TCITEM tcItem {};
+	RECT rc = pDrawItemStruct->rcItem;
 	
-	int		nTab		= pDrawItemStruct->itemID;
-	bool	isSelected	= (nTab == getActiveTb());
+	int nTab = pDrawItemStruct->itemID;
+	bool isSelected	= (nTab == getActiveTb());
 
 	// get current selected item
 	tcItem.mask = TCIF_PARAM;
@@ -1045,7 +1027,7 @@ void DockingCont::drawTabItem(DRAWITEMSTRUCT *pDrawItemStruct)
 		return;
 
 	const TCHAR *text = reinterpret_cast<tTbData*>(tcItem.lParam)->pszName;
-	int		length = lstrlen(reinterpret_cast<tTbData*>(tcItem.lParam)->pszName);
+	int length = lstrlen(reinterpret_cast<tTbData*>(tcItem.lParam)->pszName);
 
 
 	// get drawing context
@@ -1094,8 +1076,8 @@ void DockingCont::drawTabItem(DRAWITEMSTRUCT *pDrawItemStruct)
 		if ((hImageList != NULL) && (iPosImage >= 0))
 		{
 			// Get height of image so we
-			IMAGEINFO	info		= {};
-			RECT &		imageRect	= info.rcImage;
+			IMAGEINFO info {};
+			const RECT& imageRect = info.rcImage;
 			
 			ImageList_GetImageInfo(hImageList, iPosImage, &info);
 
@@ -1177,7 +1159,7 @@ intptr_t CALLBACK DockingCont::run_dlgProc(UINT Message, WPARAM wParam, LPARAM l
 			{
 				break;
 			}
-			RECT rc{};
+			RECT rc {};
 			getClientRect(rc);
 			::FillRect(reinterpret_cast<HDC>(wParam), &rc, NppDarkMode::getDarkerBackgroundBrush());
 			return TRUE;
@@ -1210,9 +1192,9 @@ intptr_t CALLBACK DockingCont::run_dlgProc(UINT Message, WPARAM wParam, LPARAM l
 		}
 		case WM_NCLBUTTONDBLCLK :
 		{
-			RECT	rcWnd		= {};
-			RECT	rcClient	= {};
-			POINT	pt			= {HIWORD(lParam), LOWORD(lParam)};
+			RECT rcWnd {};
+			RECT rcClient {};
+			POINT pt = {HIWORD(lParam), LOWORD(lParam)};
 
 			getWindowRect(rcWnd);
 			getClientRect(rcClient);
@@ -1261,9 +1243,9 @@ intptr_t CALLBACK DockingCont::run_dlgProc(UINT Message, WPARAM wParam, LPARAM l
 
 void DockingCont::onSize()
 {
-	TCITEM tcItem = {};
-	RECT rc = {};
-	RECT rcTemp = {};
+	TCITEM tcItem {};
+	RECT rc {};
+	RECT rcTemp {};
 	UINT iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
 	UINT iTabOff = 0;
 
@@ -1394,31 +1376,29 @@ void DockingCont::onSize()
 
 void DockingCont::doClose(BOOL closeAll)
 {
-	int	iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
-
 	// Always close active tab first
 	int iItemCur = getActiveTb();
-	TCITEM	tcItem	= {};
-	tcItem.mask	= TCIF_PARAM;
-	::SendMessage(_hContTab, TCM_GETITEM, iItemCur, reinterpret_cast<LPARAM>(&tcItem));
-	if (tcItem.lParam)
+	TCITEM item {};
+	item.mask = TCIF_PARAM;
+	::SendMessage(_hContTab, TCM_GETITEM, iItemCur, reinterpret_cast<LPARAM>(&item));
+	if (item.lParam)
 	{
 		// notify child windows
 		if (NotifyParent(DMM_CLOSE) == 0)
 		{
 			// delete tab
-			hideToolbar((tTbData*)tcItem.lParam);
+			hideToolbar((tTbData*)item.lParam);
 		}
 	}
 
 	// Close all other tabs if requested
 	if (closeAll)
 	{
-		iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
+		int nbItem = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
 		int iItemOff = 0;
-		for (int iItem = 0; iItem < iItemCnt; ++iItem)
+		for (int iItem = 0; iItem < nbItem; ++iItem)
 		{
-			TCITEM	tcItem	= {};
+			TCITEM tcItem {};
 			// get item data
 			selectTab(iItemOff);
 			tcItem.mask	= TCIF_PARAM;
@@ -1440,7 +1420,7 @@ void DockingCont::doClose(BOOL closeAll)
 	}
 
 	// Hide dialog window if all tabs closed
-	iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
+	int iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
 	if (iItemCnt == 0)
 	{
 		// hide dialog first
@@ -1516,7 +1496,7 @@ int DockingCont::hideToolbar(tTbData *pTbData, BOOL hideClient)
 
 void DockingCont::viewToolbar(tTbData *pTbData)
 {
-	TCITEM tcItem = {};
+	TCITEM tcItem {};
 	int iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
 
 	if (iItemCnt > 0)
@@ -1563,7 +1543,7 @@ void DockingCont::viewToolbar(tTbData *pTbData)
 
 int DockingCont::searchPosInTab(tTbData* pTbData)
 {
-	TCITEM tcItem = {};
+	TCITEM tcItem {};
 	int iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
 
 	tcItem.mask	= TCIF_PARAM;
@@ -1585,7 +1565,7 @@ void DockingCont::selectTab(int iTab)
 	if (iTab != -1)
 	{
 		const TCHAR	*pszMaxTxt	= NULL;
-		TCITEM tcItem = {};
+		TCITEM tcItem {};
 		SIZE size = {};
 		int maxWidth = 0;
 		int iItemCnt = static_cast<int32_t>(::SendMessage(_hContTab, TCM_GETITEMCOUNT, 0, 0));
@@ -1601,11 +1581,11 @@ void DockingCont::selectTab(int iTab)
 		::SetFocus(((tTbData*)tcItem.lParam)->hClient);
 
 		// Notify switch in
-		NMHDR nmhdr{};
-		nmhdr.code		= DMN_SWITCHIN;
-		nmhdr.hwndFrom	= _hSelf;
-		nmhdr.idFrom	= 0;
-		::SendMessage(reinterpret_cast<tTbData*>(tcItem.lParam)->hClient, WM_NOTIFY, nmhdr.idFrom, reinterpret_cast<LPARAM>(&nmhdr));
+		NMHDR nmhdrIn{};
+		nmhdrIn.code		= DMN_SWITCHIN;
+		nmhdrIn.hwndFrom	= _hSelf;
+		nmhdrIn.idFrom	= 0;
+		::SendMessage(reinterpret_cast<tTbData*>(tcItem.lParam)->hClient, WM_NOTIFY, nmhdrIn.idFrom, reinterpret_cast<LPARAM>(&nmhdrIn));
 
 		if (static_cast<unsigned int>(iTab) != _prevItem)
 		{
@@ -1617,11 +1597,11 @@ void DockingCont::selectTab(int iTab)
 			::ShowWindow(((tTbData*)tcItem.lParam)->hClient, SW_HIDE);
 		
 			// Notify switch off
-			NMHDR nmhdr{};
-			nmhdr.code		= DMN_SWITCHOFF;
-			nmhdr.hwndFrom	= _hSelf;
-			nmhdr.idFrom	= 0;
-			::SendMessage(((tTbData*)tcItem.lParam)->hClient, WM_NOTIFY, nmhdr.idFrom, reinterpret_cast<LPARAM>(&nmhdr));
+			NMHDR nmhdrOff{};
+			nmhdrOff.code		= DMN_SWITCHOFF;
+			nmhdrOff.hwndFrom	= _hSelf;
+			nmhdrOff.idFrom	= 0;
+			::SendMessage(((tTbData*)tcItem.lParam)->hClient, WM_NOTIFY, nmhdrOff.idFrom, reinterpret_cast<LPARAM>(&nmhdrOff));
 		}
 
 		// resize tab item
@@ -1681,8 +1661,8 @@ bool DockingCont::updateCaption()
 	if (!_hContTab)
 		return false;
 
-	TCITEM			tcItem	= {};
-	int				iItem	= getActiveTb();
+	TCITEM tcItem {};
+	int iItem = getActiveTb();
 
 	if (iItem < 0)
 		return false;
@@ -1717,8 +1697,8 @@ bool DockingCont::updateCaption()
 
 void DockingCont::focusClient()
 {
-	TCITEM		tcItem	= {};
-	int			iItem	= getActiveTb();	
+	TCITEM tcItem {};
+	int iItem = getActiveTb();	
 
 	if (iItem != -1)
 	{
