@@ -443,7 +443,7 @@ generic_string FileBrowser::getNodePath(HTREEITEM node) const
 		HTREEITEM temp = _treeView.getParent(parent);
 		if (temp == nullptr)
 		{
-			SortingData4lParam* customData = reinterpret_cast<SortingData4lParam*>(_treeView.getItemParam(parent));
+			const SortingData4lParam* customData = reinterpret_cast<SortingData4lParam*>(_treeView.getItemParam(parent));
 			folderName = customData->_rootPath;
 		}
 		parent = temp;
@@ -750,7 +750,7 @@ void FileBrowser::popupMenuCmd(int cmdID)
 		{
 			if (!selectedNode) return;
 
-			generic_string *rootPath = (generic_string *)_treeView.getItemParam(selectedNode);
+			const wstring* rootPath = (wstring *)_treeView.getItemParam(selectedNode);
 			if (_treeView.getParent(selectedNode) != nullptr || rootPath == nullptr)
 				return;
 
@@ -897,8 +897,8 @@ void FileBrowser::getDirectoryStructure(const TCHAR *dir, const std::vector<gene
 				}
 				else if (isRecursive)
 				{
-					if ((OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT(".")) != 0) && 
-						(OrdinalIgnoreCaseCompareStrings(foundData.cFileName, TEXT("..")) != 0))
+					if ((wcscmp(foundData.cFileName, TEXT(".")) != 0) && 
+						(wcscmp(foundData.cFileName, TEXT("..")) != 0))
 					{
 						generic_string pathDir(dir);
 						if (pathDir[pathDir.length() - 1] != '\\')
