@@ -19,14 +19,14 @@
 //
 // Notepad++ version: begin
 //
-#define NOTEPAD_PLUS_VERSION TEXT("Notepad++ v8.6.5")
+#define NOTEPAD_PLUS_VERSION TEXT("Notepad++ v8.6.6")
 
 // should be X.Y : ie. if VERSION_DIGITALVALUE == 4, 7, 1, 0 , then X = 4, Y = 71
 // ex : #define VERSION_VALUE TEXT("5.63\0")
-#define VERSION_INTERNAL_VALUE TEXT("8.65\0")
+#define VERSION_INTERNAL_VALUE TEXT("8.66\0")
 
-#define VERSION_PRODUCT_VALUE TEXT("8.6.5\0")
-#define VERSION_DIGITALVALUE 8, 6, 5, 0
+#define VERSION_PRODUCT_VALUE TEXT("8.6.6\0")
+#define VERSION_DIGITALVALUE 8, 6, 6, 0
 
 // Notepad++ version: end
 
@@ -439,6 +439,9 @@
     //#define IDC_KEY_SELECT_2_HOME            (IDCMD+8)
     //#define IDC_KEY_SELECT_2_END            (IDCMD+9)
 
+	#define IDC_NEXT_TAB                   IDC_NEXT_DOC
+	#define IDC_PREV_TAB                   IDC_PREV_DOC
+
 #define IDCMD_LIMIT                        (IDCMD+20)
 
 #define IDSCINTILLA 60000
@@ -606,7 +609,7 @@
 	#define NPPM_INTERNAL_RELOADNATIVELANG              (NOTEPADPLUS_USER_INTERNAL + 25)
 	#define NPPM_INTERNAL_PLUGINSHORTCUTMOTIFIED        (NOTEPADPLUS_USER_INTERNAL + 26)
 	#define NPPM_INTERNAL_SCINTILLAFINDERCLEARALL       (NOTEPADPLUS_USER_INTERNAL + 27)
-	#define NPPM_INTERNAL_CHANGETABBAEICONS             (NOTEPADPLUS_USER_INTERNAL + 28)
+	#define NPPM_INTERNAL_CHANGETABBARICONSET           (NOTEPADPLUS_USER_INTERNAL + 28)
 	#define NPPM_INTERNAL_SETTING_TAB_REPLCESPACE       (NOTEPADPLUS_USER_INTERNAL + 29)
 	#define NPPM_INTERNAL_SETTING_TAB_SIZE              (NOTEPADPLUS_USER_INTERNAL + 30)
 	#define NPPM_INTERNAL_RELOADSTYLERS                 (NOTEPADPLUS_USER_INTERNAL + 31)
